.. _documentation:

Documentation
===================

Contents:

.. toctree::
   :maxdepth: 2

   introduction
   mission
   installation
   examples_index
   faq
   developers
   cite
   devel/index
   theory/index
   reference/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

